@@ -71,48 +71,48 @@
 
 /***ja
     @addtogroup m17nDatabase
-    @brief m17n ǡ١ˤȤ˴ؤ API.
+    @brief m17n データベースにとそれに関する API.
 
-    m17n 饤֥ɬפ˱ưŪ @e m17n @e ǡ١ 
-    롣ޤץꥱץ⡢ȼΥǡ 
-    m17n ǡ١ɲäưŪ˼뤳ȤǤ롣
-    ץꥱץबȼΥǡɲáˤϡѿ 
-    #mdatabase_dir ˤΥץꥱͭΥǥ쥯ȥ򥻥åȤ
-    ˥ǡǼ롣桼Υǡ򥪡С饤Ȥ
-    ȤϡĶѿ "M17NDIR" ǻꤵǥ쥯ȥʻꤵƤ
-    Ȥ "~/.m17n.d" Ȥǥ쥯ȥˤ̤Υǡ֤
+    m17n ライブラリは必要に応じて動的に @e m17n @e データベース 
+    から情報を取得する。またアプリケーションプログラムも、独自のデータを 
+    m17n データベースに追加し、それを動的に取得することができる。
+    アプリケーションプログラムが独自のデータを追加・取得するには、変数 
+    #mdatabase_dir にそのアプリケーション固有のディレクトリをセットし、
+    その中にデータを格納する。ユーザがそのデータをオーバーライトしたい
+    ときは、環境変数 "M17NDIR" で指定されるディレクトリ（指定されていな
+    いときは "~/.m17n.d" というディレクトリ）に別のデータを置く。
 
     m17n 
-    ǡ١ˤʣ¿ͤʥǡޤޤƤꡢƥǡ
-    TAG0, TAG1, TAG2, TAG3ʤ٤ƥܥˤΣĤΥˤäƼ̤롣
+    データベースには複数の多様なデータが含まれており、各データは
+    TAG0, TAG1, TAG2, TAG3（すべてシンボル）の４つのタグによって識別される。
 
-    TAG0 ˤäơǡ١ΥǡΥפϼΤ褦˻ꤵ롣
+    TAG0 によって、データベース内のデータのタイプは次のように指定される。
 
     @li 
-    TAG0  #Mchar_table Ǥǡ @e chartable 
-    ȸƤФ졢ʸ˴ؤ󶡤롣ξ
-    TAG1 Ͼμꤹ륷ܥǤꡢ#Msymbol, #Minteger, #Mstring,
-    #Mtext, #Mplist Τ줫Ǥ롣TAG2  TAG3 ǤդΥܥǤ褤
+    TAG0 が #Mchar_table であるデータは @e chartableタイプ 
+    と呼ばれ、各文字に関する情報を提供する。この場合
+    TAG1 は情報の種類を指定するシンボルであり、#Msymbol, #Minteger, #Mstring,
+    #Mtext, #Mplist のいずれかである。TAG2 と TAG3 は任意のシンボルでよい。
 
     @li 
-    TAG0  #Mcharset Ǥǡ @e charset 
-    ȸƤФ졢ʸåѤΥǥɡ󥳡ɥޥåפ󶡤롣ξ TAG1
-    ʸåȤΥܥǤʤФʤʤTAG2  TAG3
-    ǤդΥܥǤ褤
+    TAG0 が #Mcharset であるデータは @e charsetタイプ 
+    と呼ばれ、文字セット用のデコード／エンコードマップを提供する。この場合 TAG1
+    は文字セットのシンボルでなければならない。TAG2 と TAG3
+    は任意のシンボルでよい。
 
     @li
-    TAG0  #Mchar_table Ǥ #Mcharset Ǥʤ硢Υǡ @e
-    plist Ǥ롣ܺ٤˴ؤƤϴؿ mdatabase_load () 
-    򻲾ȤΤȡξ TAG1TAG2TAG3 ǤդΥܥǤ褤
+    TAG0 が #Mchar_table でも #Mcharset でもない場合、そのデータは @e
+    plistタイプ である。詳細に関しては関数 mdatabase_load () 
+    の説明を参照のこと。この場合 TAG1、TAG2、TAG3 は任意のシンボルでよい。
 
-    Υĥǡ١ \<TAG0, TAG1, TAG2, TAG3\> 
-    Ȥɽ
+    特定のタグを持つデータベースを \<TAG0, TAG1, TAG2, TAG3\> 
+    という形式で表す。
 
-    ץꥱץϡޤؿ mdatabase_find () 
-    Ȥäƥǡ١˴ؤݻ륪֥ȡ#MDatabase
-    ˤؤΥݥ󥿤롣顢 mdatabase_load () 
-    ˤäƼºݤ˥ǡ١ɤ롣¤ #MDatabase 
-    ȤɤƤ뤫ϡץꥱץफϸʤ
+    アプリケーションプログラムは、まず関数 mdatabase_find () 
+    を使ってデータベースに関する情報を保持するオブジェクト（#MDatabase
+    型）へのポインタを得る。それに成功したら、 mdatabase_load () 
+    によって実際にデータベースをロードする。構造体 #MDatabase 
+    自身がどう実装されているかは、アプリケーションプログラムからは見えない。
 
     @latexonly \IPAlabel{database} @endlatexonly
 */
@@ -1226,9 +1226,8 @@ mdatabase__props (MDatabase *mdb)
 
 /* External API */
 
-/*** @addtogroup m17nCharset */
-/*** @{ */
-/*=*/
+/*** @addtogroup m17nCharset
+     @{ */
 /***en
     @brief The symbol @c Mcharset.
 
@@ -1237,21 +1236,20 @@ mdatabase__props (MDatabase *mdb)
     <tt>"charset"</tt>.  */
 
 /***ja
-    @brief ܥ @c Mcharset.
+    @brief シンボル @c Mcharset.
 
-    ǥɤ줿 M-text ϡ @c Mcharset
-    Ǥ褦ʥƥȥץѥƥġ
-    ܥ @c Mcharset  <tt>"charset"</tt> Ȥ̾ġ  */
+    デコードされた M-text は、キーが @c Mcharset
+    であるようなテキストプロパティを持つ。
+    シンボル @c Mcharset は <tt>"charset"</tt> という名前を持つ。  */
 
 MSymbol Mcharset;
 /*=*/
 /*** @} */
 /*=*/
 
-/*** @addtogroup m17nDatabase */
-/*** @{ */
+/*** @addtogroup m17nDatabase
+     @{ */
 
-/*=*/
 /***en
     @brief Directory for application specific data.
 
@@ -1264,15 +1262,15 @@ MSymbol Mcharset;
 
     The default value is NULL.  */
 /***ja
-    @brief ץꥱͭΥǡѥǥ쥯ȥ.
+    @brief アプリケーション固有のデータ用ディレクトリ.
 
-    ץꥱץबΥץͭΥǡ m17n 
-    ǡ١񤭤ǡ󶡤ˤϡޥ M17N_INIT () 
-    Ƥˤѿǡեޤǥ쥯ȥ̾˥åȤʤƤϤʤʤǥ쥯ȥˤ
-    "mdb.dir" ե򤪤ȤǤ롣"mdb.dir"եˤϡ 
-    @ref mdbDir "mdbDir(5)" ƤեޥåȤǥǡΥꥹȤ򵭽Ҥ롣
+    アプリケーションプログラムが、そのプログラム固有のデータや m17n 
+    データベースを上書きするデータを提供する場合には、マクロ M17N_INIT () 
+    を呼ぶ前にこの変数をデータファイルを含むディレクトリ名にセットしなくてはならない。ディレクトリには
+    "mdb.dir" ファイルをおくことができる。その"mdb.dir"ファイルには、 
+    @ref mdbDir "mdbDir(5)" で説明されているフォーマットでデータ定義のリストを記述する。
 
-    ǥեȤͤ NULL Ǥ롣  */
+    デフォルトの値は NULL である。  */
 
 char *mdatabase_dir;
 
@@ -1285,11 +1283,11 @@ char *mdatabase_dir;
     the data.  If such a data is not found, it returns @c NULL.  */
 
 /***ja
-    @brief ǡ١Υǡõ.
+    @brief データベース中のデータを探す.
 
-    ؿ mdatabase_find () ϡ m17n ١ $TAG0  
-    $TAG3 ޤǤΥĥǡõؤΥݥ󥿤֤Τ褦ʥǡʤ
-    @c NULL ֤
+    関数 mdatabase_find () は、 m17n 言語情報ベース中で $TAG0 から 
+    $TAG3 までのタグを持つデータを探し、それへのポインタを返す。そのようなデータがなければ
+    @c NULL を返す。
 
     @latexonly \IPAlabel{mdatabase_find} @endlatexonly  */
 
@@ -1313,12 +1311,12 @@ mdatabase_find (MSymbol tag0, MSymbol tag1, MSymbol tag2, MSymbol tag3)
     any tag.  Each element of the plist has key #Mt and value a
     pointer to type #MDatabase.  */
 /***ja
-    @brief m17n ǡ١ΥǡꥹȤ֤.
+    @brief m17n データベースのデータリストを返す.
 
-    ؿ mdatabase_list ()  m17n ǡ١椫 $TAG0 $TAG3 
-    ޤǤΥĥǡõΥꥹȤplist Ȥ֤ $TAGn  #Mnil
-    ǤäˤϡǤդΥ˥ޥå磻ɥɤȤƼ갷롣֤
-    plist γǤϥ Ȥ #Mt ͤȤ #MDatabase ؤΥݥ󥿤ġ  */
+    関数 mdatabase_list () は m17n データベース中から $TAG0 から$TAG3 
+    までのタグを持つデータを探し、そのリストをplist として返す。 $TAGn が #Mnil
+    であった場合には、任意のタグにマッチするワイルドカードとして取り扱われる。返される
+    plist の各要素はキー として #Mt を、値として #MDatabase 型へのポインタを持つ。  */
 
 MPlist *
 mdatabase_list (MSymbol tag0, MSymbol tag1, MSymbol tag2, MSymbol tag3)
@@ -1410,22 +1408,22 @@ mdatabase_list (MSymbol tag0, MSymbol tag1, MSymbol tag2, MSymbol tag3)
     mdatabase_load ().  Otherwise, it returns @c NULL.  */
 
 /***ja
-    @brief m17n ǡ١Υǡ.
+    @brief m17n データベースのデータを定義する.
 
-    ؿ mdatabase_define ()  $TAG0  $TAG3 ޤǤΥղþ 
-    $EXTRA_INFO ĥǡ롣
+    関数 mdatabase_define () は $TAG0 から $TAG3 までのタグおよび付加情報 
+    $EXTRA_INFO を持つデータを定義する。
 
-    $LOADER ϤΥǡΥɤѤؿؤΥݥ󥿤Ǥ롣δؿ
-    mdatabase_load ()  $TAGS  $EXTRA_INFO ȤĤΰդǸƤӽФ롣 
-    $TAGS  $TAG0  $TAG3 ޤǤǤ롣
+    $LOADER はそのデータのロードに用いられる関数へのポインタである。この関数は
+    mdatabase_load () から $TAGS と $EXTRA_INFO という二つの引数付きで呼び出される。ここで 
+    $TAGS は $TAG0 から $TAG3 までの配列である。
 
-    ⤷ $LOADER  @c NULL ʤ顢m17n 饤֥ɸΥȤ롣ξˤ
-    $EXTRA_INFO ϥǡޤե̾ǤʤƤϤʤʤ
+    もし $LOADER が @c NULL なら、m17n ライブラリ標準のローダが使われる。この場合には
+    $EXTRA_INFO はデータを含むファイル名でなくてはならない。
 
     @return
-     mdatabase_define () 
-    줿ǡ١ؤΥݥ󥿤֤Υݥ󥿤ϴؿ mdatabase_load () 
-    ΰȤѤ뤳ȤǤ롣Ǥʤ @c NULL ֤
+    処理に成功すれば mdatabase_define () 
+    は定義されたデータベースへのポインタを返す。このポインタは関数 mdatabase_load () 
+    の引数として用いることができる。そうでなければ @c NULL を返す。
 
     @latexonly \IPAlabel{mdatabase_define} @endlatexonly  */
 
@@ -1476,24 +1474,24 @@ mdatabase_define (MSymbol tag0, MSymbol tag1, MSymbol tag2, MSymbol tag3,
 
 
 /***ja
-    @brief ǡ١ǡɤ.
+    @brief データベースからデータをロードする.
 
-    ؿ mdatabase_load ()  $MDB 
-    ؤǡɤȤ֤֤ΤϥǡΥפˤäưۤʤ롣
+    関数 mdatabase_load () は $MDB 
+    が指すデータをロードし、その中身を返す。返されるものはデータのタイプによって異なる。
 
-    ǡ @e plist ʤС @e plist ؤΥݥ󥿤֤
+    データが @e plistタイプ ならば、 @e plist へのポインタを返す。
 
-    ǡ @e chartable ʤʸơ֥֤
-    ʸơ֥Υǥեͤϡǡ2ˤäưʲΤ褦˷ޤ롣
+    データが @e chartableタイプ ならば文字テーブルを返す。
+    文字テーブルのデフォルト値は、データの第2タグによって以下のように決まる。
 
-    @li  #Msymbol ʤ顢ǥեͤ #Mnil
-    @li  #Minteger ʤ顢ǥեͤ -1
-    @li ʳʤ顢ǥեͤ @c NULL
+    @li タグが #Msymbol なら、デフォルト値は #Mnil
+    @li タグが #Minteger なら、デフォルト値は -1
+    @li それ以外なら、デフォルト値は @c NULL
 
-    ǡ @e charset ʤĹ 2  plist ֤ʥ϶#Mt ˡ
-    ǽǤͤϥɥݥȤбʸɤ˥ޥåפǤ롣
-    ܤǤͤϵդΥޥåפ򤹤ʸơ֥Ǥ롣
-    ʸåȤͽƤʤФʤʤ
+    データが @e charsetタイプ ならば長さ 2 の plist を返す（キーは共に#Mt ）。
+    最初の要素の値はコードポイントを対応する文字コードにマップする整数の配列である。
+    ２番目の要素の値は逆のマップをする文字テーブルである。
+    この文字セットは予め定義されていなければならない。
 
     @latexonly \IPAlabel{mdatabase_load} @endlatexonly
   */
@@ -1517,10 +1515,10 @@ mdatabase_load (MDatabase *mdb)
     four.  */
 
 /***ja
-    @brief ǡΥ.
+    @brief データのタグを得る.
 
-    ؿ mdatabase_tag () ϡǡ $MDB Υʥܥˤ֤Ĺ
-    4 Ǥ롣
+    関数 mdatabase_tag () は、データ $MDB のタグ（シンボル）の配列を返す。配列の長さは
+    4 である。
 
     @latexonly \IPAlabel{mdatabase_tag} @endlatexonly  */
 
@@ -1534,6 +1532,6 @@ mdatabase_tag (MDatabase *mdb)
 
 /*
   Local Variables:
-  coding: euc-japan
+  coding: utf-8
   End:
 */
